@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 03 Feb 2009 11:13:00 JST
+ *  Last-modified: Wed 25 Mar 2009 14:26:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_HEXDUMP_H
@@ -108,6 +108,12 @@ namespace clx {
 		return hexdump(src.begin(), src.end(), dest, prefix);
 	}
 	
+	template <class Ch, class Tr, class OutIter>
+	OutIter hexdump(const std::basic_string<Ch, Tr>& src, OutIter dest, const Ch* prefix) {
+		std::basic_string<Ch, Tr> tmp(prefix);
+		return hexdump(src, dest, tmp);
+	}
+	
 	/* --------------------------------------------------------------------- */
 	//  hexdump
 	/* --------------------------------------------------------------------- */
